@@ -32,7 +32,7 @@ Net::WebSocket::Frame::close
     my $serialized = $frm->to_bytes();
 
 Note that, L<as per RFC 6455|https://tools.ietf.org/html/rfc6455#section-5.5>,
-close messages can either have:
+close messages can have any of:
 
 =over
 
@@ -51,23 +51,33 @@ constants that L<Microsoft defines|https://msdn.microsoft.com/en-us/library/wind
 
 =over
 
-=item * SUCCESS (1000)
+=item * C<SUCCESS> (1000)
 
-=item * ENDPOINT_UNAVAILABLE (1001)
+=item * C<ENDPOINT_UNAVAILABLE> (1001)
 
-=item * PROTOCOL_ERROR (1002)
+=item * C<PROTOCOL_ERROR> (1002)
 
-=item * INVALID_DATA_TYPE (1003)
+=item * C<INVALID_DATA_TYPE> (1003)
 
-=item * INVALID_PAYLOAD (1007)
+=item * C<INVALID_PAYLOAD> (1007)
 
-=item * POLICY_VIOLATION (1008)
+=item * C<POLICY_VIOLATION> (1008)
 
-=item * MESSAGE_TOO_BIG (1009)
+=item * C<MESSAGE_TOO_BIG> (1009)
 
-=item * UNSUPPORTED_EXTENSIONS (1010)
+=item * C<UNSUPPORTED_EXTENSIONS> (1010)
 
-=item * SERVER_ERROR (1011)
+=item * C<SERVER_ERROR> (1011)
+
+NOTE: As per L<erratum|https://www.rfc-editor.org/errata_search.php?rfc=6455>
+3227, this status is meant to encompass client errors as well. Since these
+constants are meant to match Microsoft’s (in default of such in the actual
+WebSocket standard), however, Net::WebSocket only recognizes C<SERVER_ERROR>
+as an alias of 1011. Hopefully a future update to the WebSocket standard will
+include useful string aliases for the status codes.
+
+Also note that L<the official list of status codes|http://www.iana.org/assignments/websocket/websocket.xhtml#close-code-number> contains some that
+don’t have string constants.
 
 =back
 
@@ -89,7 +99,7 @@ use constant get_opcode => 8;
 sub new {
     my ($class, %opts) = @_;
 
-    if (!$opts{'payload_sr'}) {
+    if (!$opts{'payload_sr'} && !defined $opts{'payload'}) {
         my $payload;
 
         if ($opts{'code'}) {
@@ -98,12 +108,12 @@ sub new {
                 $num = $opts{'code'};
 
                 if ($num !~ m<\A[0-9]{4}\z> ) {
-                    die "Invalid WebSocket status code: [$num]";
+                    die Net::WebSocket::X->create('BadArg', 'code', $num, 'Invalid WebSocket status code');
                 }
 
                 if ( !Net::WebSocket::Constants::status_code_to_name($num) ) {
                     if ( $num < 4000 || $num > 4999 ) {
-                        die "Disallowed WebSocket status code: [$num]";
+                        die Net::WebSocket::X->create('BadArg', 'code', $num, 'Disallowed WebSocket status code');
                     }
                 }
             }
@@ -112,7 +122,7 @@ sub new {
 
             if (defined $opts{'reason'}) {
                 if (length $opts{'reason'} > 123) {
-                    die "“reason” ($opts{'reason'}) cannot exceed 123 bytes!";
+                    die Net::WebSocket::X->create('BadArg', 'reason', $opts{'reason'}, 'Reason cannot exceed 123 bytes!');
                 }
 
                 $payload .= $opts{'reason'};
@@ -122,10 +132,10 @@ sub new {
             $payload = q<>;
         }
 
-        $opts{'payload_sr'} = \$payload;
+        $opts{'payload'} = $payload;
     }
 
-    return $class->SUPER::new( %opts, type => 'close' );
+    return $class->SUPER::new( %opts );
 }
 
 sub get_code_and_reason {
@@ -133,6 +143,7 @@ sub get_code_and_reason {
 
     Call::Context::must_be_list();
 
+    #This shouldn’t happen … maybe leftover from previous architecture?
     if ($self->get_type() ne 'close') {
         my $type = $self->get_type();
         die "Frame type is “$type”, not “close” as expected!";
